# EC Ecology Toolbox

[![C/C++ CI](https://github.com/emilydolson/ec_ecology_toolbox/actions/workflows/c-cpp.yml/badge.svg)](https://github.com/emilydolson/ec_ecology_toolbox/actions/workflows/c-cpp.yml) 
[![Python CI](https://github.com/emilydolson/ec_ecology_toolbox/actions/workflows/python_ci.yml/badge.svg)](https://github.com/emilydolson/ec_ecology_toolbox/actions/workflows/python_ci.yml)
[![codecov](https://codecov.io/gh/emilydolson/ec_ecology_toolbox/branch/master/graph/badge.svg)](https://codecov.io/gh/emilydolson/ec_ecology_toolbox)
[![PyPi Package Version](https://img.shields.io/pypi/v/ec-ecology-toolbox.svg)](https://pypi.python.org/pypi/ec-ecology-toolbox)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/ec-ecology-toolbox)
